#!/bin/bash

##################################################################
#Set application name
appName=FisPro

# Define minimum java version
minJavaVersionMajor=1
minJavaVersionMinor=8
minJavaVersionPatch=0

# env var $JAVA_OPTS is set with default values if not set
##################################################################

FISPRO_PATH="`dirname \"$0\"`"
FISPRO_PATH="`( cd \"$FISPRO_PATH\" && pwd )`"
cd $FISPRO_PATH

JAVA=java

if [ -n "$JAVA_HOME" ]; then
  JAVA="$JAVA_HOME/bin/java"
fi

# Check JAVA_OPTS and set with defaults if not set
if [ -z "$JAVA_OPTS" ]; then
  # Add what you like...
  JAVA_OPTS="-Xms512m -Xmx1024m "
fi

# Java Discovery
if ( which $JAVA 2>&1 > /dev/null ); then
  echo -n ''
else
  echo 'Cannot find Java. Please install Java or set your JAVA_HOME environment variable.'
  exit 1
fi

# Check Java Version
javaVersion=`$JAVA -version 2>&1 | awk 'NR==1{ gsub(/"/,""); print $3 }'`
javaVersionMajor=`echo $javaVersion | awk -F . '{print $1}'`
javaVersionMinor=`echo $javaVersion | awk -F . '{print $2}'`
javaVersionPatch=`echo $javaVersion | awk -F . '{print $3}' | awk -F _ '{print $2}'`

if [ $javaVersionMajor -gt $minJavaVersionMajor ]; then
echo -n ''
else
  if [ $javaVersionMajor -eq $minJavaVersionMajor ] &&
     [ $javaVersionMinor -gt $minJavaVersionMinor ]; then
    echo -n ''
  else
    if [ $javaVersionMajor -eq $minJavaVersionMajor ] &&
       [ $javaVersionMinor -eq $minJavaVersionMinor ] &&
       [ $javaVersionPatch -ge $minJavaVersionPatch ]; then
      echo -n ''
    else
 	  echo "Found Java version:    $javaVersionMajor.$javaVersionMinor.$javaVersionPatch"
	  echo "Required Java version: $minJavaVersionMajor.$minJavaVersionMinor.$minJavaVersionPatch"
      echo 'Please update your Java to the required Java version !'
      exit 1;
    fi
  fi
fi

# Launch FisPro
export LC_NUMERIC=C
exec -a $appName $JAVA $JAVA_OPTS -splash:fispro-splash.png -classpath *:lib/*:help fis.MainFIS
